@@ -142,7 +142,7 @@ def lens_dirt_node(
 
 
 @gin.configurable
-def render_aov(
+def render(
     rgb_path: Union[Path, str] = None,
     depth_path: Union[Path, str] = None,
     iseg_path: Union[Path, str] = None,
@@ -237,7 +237,7 @@ def render_aov(
         for style, output_path in render_outputs.items():
             if output_path is not None:
                 break
-        _filename = f'blender-debug-post-{output_path.stem}.blend'
+        _filename = f'_debug.post.{output_path.stem}.blend'
         _path = output_path.parent / _filename
         zpy.blender.save_debug_blenderfile(_path)
 
@@ -249,6 +249,11 @@ def render_aov(
             log.info(f'Rendered {style} image saved to {str(output_path)}')
 
 
+# TODO: Eventually remove this deprecated function name
+def render_aov(*args, **kwargs):
+    return render(*args, **kwargs)
+
+
 def _mute_aov_file_output_node(style: str, mute: bool = True):
     """ Mute (or un-mute) an AOV output node for a style. """
     log.debug(f'Muting AOV node for {style}')
